PrometheusLayerBuilder

Struct PrometheusLayerBuilder 

pub struct PrometheusLayerBuilder { /* private fields */ }
PrometheusLayerBuilder is a config builder to build a PrometheusLayer.

Implementations

Source

impl PrometheusLayerBuilder

pub fn bytes_buckets(self, buckets: Vec<f64>) -> Self

Set buckets for bytes related histogram like operation_bytes.

pub fn bytes_rate_buckets(self, buckets: Vec<f64>) -> Self

Set buckets for bytes rate related histogram like operation_bytes_rate.

pub fn entries_buckets(self, buckets: Vec<f64>) -> Self

Set buckets for entries related histogram like operation_entries.

pub fn entries_rate_buckets(self, buckets: Vec<f64>) -> Self

Set buckets for entries rate related histogram like operation_entries_rate.

pub fn duration_seconds_buckets(self, buckets: Vec<f64>) -> Self

Set buckets for duration seconds related histogram like operation_duration_seconds.

pub fn ttfb_buckets(self, buckets: Vec<f64>) -> Self

Set buckets for ttfb related histogram like operation_ttfb_seconds.

pub fn register(self, registry: &Registry) -> Result<PrometheusLayer>

Register the metrics into the given registry and return a PrometheusLayer.

Example
// Pick a builder and configure it.
let builder = services::Memory::default();
let _ = Operator::new(builder)?
    .layer(
        PrometheusLayer::builder()
            .register(prometheus::default_registry())
            .expect("register metrics successfully"),
    );
pub fn register_default(self) -> Result<PrometheusLayer>

Register the metrics into the default registry and return a PrometheusLayer.

Example
// Pick a builder and configure it.
let builder = services::Memory::default();
let _ = Operator::new(builder)?
    .layer(
        PrometheusLayer::builder()
            .register_default()
            .expect("register metrics successfully"),
    );